@@ -340,9 +340,7 @@ TEST_DECLARE(glmc_quat_from_vecs)
 /* bezier */
 TEST_DECLARE(bezier)
 
-
-/* Macros */
-
+/* vec2 */
 TEST_DECLARE(MACRO_GLM_VEC2_ONE_INIT)
 TEST_DECLARE(MACRO_GLM_VEC2_ZERO_INIT)
 TEST_DECLARE(MACRO_GLM_VEC2_ONE)
@@ -385,7 +383,6 @@ TEST_DECLARE(glm_vec2_lerp)
 TEST_DECLARE(glm_vec2_complex_mul)
 TEST_DECLARE(glm_vec2_complex_div)
 
-
 TEST_DECLARE(glmc_vec2)
 TEST_DECLARE(glmc_vec2_copy)
 TEST_DECLARE(glmc_vec2_zero)
@@ -588,7 +585,6 @@ TEST_DECLARE(glmc_vec3_hadd)
 TEST_DECLARE(glmc_vec3_sqrt)
 
 /* vec4 */
-
 TEST_DECLARE(MACRO_GLM_VEC4_ONE_INIT)
 TEST_DECLARE(MACRO_GLM_VEC4_ZERO_INIT)
 TEST_DECLARE(MACRO_GLM_VEC4_ONE)
@@ -734,8 +730,106 @@ TEST_DECLARE(glmc_vec4_fract)
 TEST_DECLARE(glmc_vec4_hadd)
 TEST_DECLARE(glmc_vec4_sqrt)
 
-/* structs */
+/* ivec2 */
+TEST_DECLARE(glm_ivec2)
+TEST_DECLARE(glm_ivec2_copy)
+TEST_DECLARE(glm_ivec2_zero)
+TEST_DECLARE(glm_ivec2_one)
+TEST_DECLARE(glm_ivec2_add)
+TEST_DECLARE(glm_ivec2_adds)
+TEST_DECLARE(glm_ivec2_sub)
+TEST_DECLARE(glm_ivec2_subs)
+TEST_DECLARE(glm_ivec2_mul)
+TEST_DECLARE(glm_ivec2_scale)
+TEST_DECLARE(glm_ivec2_distance2)
+TEST_DECLARE(glm_ivec2_distance)
+TEST_DECLARE(glm_ivec2_maxv)
+TEST_DECLARE(glm_ivec2_minv)
+TEST_DECLARE(glm_ivec2_clamp)
 
+TEST_DECLARE(glmc_ivec2)
+TEST_DECLARE(glmc_ivec2_copy)
+TEST_DECLARE(glmc_ivec2_zero)
+TEST_DECLARE(glmc_ivec2_one)
+TEST_DECLARE(glmc_ivec2_add)
+TEST_DECLARE(glmc_ivec2_adds)
+TEST_DECLARE(glmc_ivec2_sub)
+TEST_DECLARE(glmc_ivec2_subs)
+TEST_DECLARE(glmc_ivec2_mul)
+TEST_DECLARE(glmc_ivec2_scale)
+TEST_DECLARE(glmc_ivec2_distance2)
+TEST_DECLARE(glmc_ivec2_distance)
+TEST_DECLARE(glmc_ivec2_maxv)
+TEST_DECLARE(glmc_ivec2_minv)
+TEST_DECLARE(glmc_ivec2_clamp)
+
+/* ivec3 */
+TEST_DECLARE(glm_ivec3)
+TEST_DECLARE(glm_ivec3_copy)
+TEST_DECLARE(glm_ivec3_zero)
+TEST_DECLARE(glm_ivec3_one)
+TEST_DECLARE(glm_ivec3_add)
+TEST_DECLARE(glm_ivec3_adds)
+TEST_DECLARE(glm_ivec3_sub)
+TEST_DECLARE(glm_ivec3_subs)
+TEST_DECLARE(glm_ivec3_mul)
+TEST_DECLARE(glm_ivec3_scale)
+TEST_DECLARE(glm_ivec3_distance2)
+TEST_DECLARE(glm_ivec3_distance)
+TEST_DECLARE(glm_ivec3_maxv)
+TEST_DECLARE(glm_ivec3_minv)
+TEST_DECLARE(glm_ivec3_clamp)
+
+TEST_DECLARE(glmc_ivec3)
+TEST_DECLARE(glmc_ivec3_copy)
+TEST_DECLARE(glmc_ivec3_zero)
+TEST_DECLARE(glmc_ivec3_one)
+TEST_DECLARE(glmc_ivec3_add)
+TEST_DECLARE(glmc_ivec3_adds)
+TEST_DECLARE(glmc_ivec3_sub)
+TEST_DECLARE(glmc_ivec3_subs)
+TEST_DECLARE(glmc_ivec3_mul)
+TEST_DECLARE(glmc_ivec3_scale)
+TEST_DECLARE(glmc_ivec3_distance2)
+TEST_DECLARE(glmc_ivec3_distance)
+TEST_DECLARE(glmc_ivec3_maxv)
+TEST_DECLARE(glmc_ivec3_minv)
+TEST_DECLARE(glmc_ivec3_clamp)
+
+/* ivec4 */
+TEST_DECLARE(glm_ivec4)
+TEST_DECLARE(glm_ivec4_copy)
+TEST_DECLARE(glm_ivec4_zero)
+TEST_DECLARE(glm_ivec4_one)
+TEST_DECLARE(glm_ivec4_add)
+TEST_DECLARE(glm_ivec4_adds)
+TEST_DECLARE(glm_ivec4_sub)
+TEST_DECLARE(glm_ivec4_subs)
+TEST_DECLARE(glm_ivec4_mul)
+TEST_DECLARE(glm_ivec4_scale)
+TEST_DECLARE(glm_ivec4_distance2)
+TEST_DECLARE(glm_ivec4_distance)
+TEST_DECLARE(glm_ivec4_maxv)
+TEST_DECLARE(glm_ivec4_minv)
+TEST_DECLARE(glm_ivec4_clamp)
+
+TEST_DECLARE(glmc_ivec4)
+TEST_DECLARE(glmc_ivec4_copy)
+TEST_DECLARE(glmc_ivec4_zero)
+TEST_DECLARE(glmc_ivec4_one)
+TEST_DECLARE(glmc_ivec4_add)
+TEST_DECLARE(glmc_ivec4_adds)
+TEST_DECLARE(glmc_ivec4_sub)
+TEST_DECLARE(glmc_ivec4_subs)
+TEST_DECLARE(glmc_ivec4_mul)
+TEST_DECLARE(glmc_ivec4_scale)
+TEST_DECLARE(glmc_ivec4_distance2)
+TEST_DECLARE(glmc_ivec4_distance)
+TEST_DECLARE(glmc_ivec4_maxv)
+TEST_DECLARE(glmc_ivec4_minv)
+TEST_DECLARE(glmc_ivec4_clamp)
+
+/* structs */
 TEST_DECLARE(mat3s_identity_init)
 TEST_DECLARE(mat3s_zero_init)
 TEST_DECLARE(mat4s_identity_init)
@@ -1075,8 +1169,6 @@ TEST_LIST {
   TEST_ENTRY(bezier)
 
   /* vec2 */
-  /* Macros */
-
   TEST_ENTRY(MACRO_GLM_VEC2_ONE_INIT)
   TEST_ENTRY(MACRO_GLM_VEC2_ZERO_INIT)
   TEST_ENTRY(MACRO_GLM_VEC2_ONE)
@@ -1157,8 +1249,6 @@ TEST_LIST {
   TEST_ENTRY(glmc_vec2_complex_div)
 
   /* vec3 */
-  /* Macros */
-
   TEST_ENTRY(MACRO_GLM_VEC3_ONE_INIT)
   TEST_ENTRY(MACRO_GLM_VEC3_ZERO_INIT)
   TEST_ENTRY(MACRO_GLM_VEC3_ONE)
@@ -1322,8 +1412,6 @@ TEST_LIST {
   TEST_ENTRY(glmc_vec3_sqrt)
 
   /* vec4 */
-  /* Macros */
-
   TEST_ENTRY(MACRO_GLM_VEC4_ONE_INIT)
   TEST_ENTRY(MACRO_GLM_VEC4_ZERO_INIT)
   TEST_ENTRY(MACRO_GLM_VEC4_ONE)
@@ -1469,6 +1557,105 @@ TEST_LIST {
   TEST_ENTRY(glmc_vec4_hadd)
   TEST_ENTRY(glmc_vec4_sqrt)
 
+  /* ivec2 */
+  TEST_ENTRY(glm_ivec2)
+  TEST_ENTRY(glm_ivec2_copy)
+  TEST_ENTRY(glm_ivec2_zero)
+  TEST_ENTRY(glm_ivec2_one)
+  TEST_ENTRY(glm_ivec2_add)
+  TEST_ENTRY(glm_ivec2_adds)
+  TEST_ENTRY(glm_ivec2_sub)
+  TEST_ENTRY(glm_ivec2_subs)
+  TEST_ENTRY(glm_ivec2_mul)
+  TEST_ENTRY(glm_ivec2_scale)
+  TEST_ENTRY(glm_ivec2_distance2)
+  TEST_ENTRY(glm_ivec2_distance)
+  TEST_ENTRY(glm_ivec2_maxv)
+  TEST_ENTRY(glm_ivec2_minv)
+  TEST_ENTRY(glm_ivec2_clamp)
+
+  TEST_ENTRY(glmc_ivec2)
+  TEST_ENTRY(glmc_ivec2_copy)
+  TEST_ENTRY(glmc_ivec2_zero)
+  TEST_ENTRY(glmc_ivec2_one)
+  TEST_ENTRY(glmc_ivec2_add)
+  TEST_ENTRY(glmc_ivec2_adds)
+  TEST_ENTRY(glmc_ivec2_sub)
+  TEST_ENTRY(glmc_ivec2_subs)
+  TEST_ENTRY(glmc_ivec2_mul)
+  TEST_ENTRY(glmc_ivec2_scale)
+  TEST_ENTRY(glmc_ivec2_distance2)
+  TEST_ENTRY(glmc_ivec2_distance)
+  TEST_ENTRY(glmc_ivec2_maxv)
+  TEST_ENTRY(glmc_ivec2_minv)
+  TEST_ENTRY(glmc_ivec2_clamp)
+
+  /* ivec3 */
+  TEST_ENTRY(glm_ivec3)
+  TEST_ENTRY(glm_ivec3_copy)
+  TEST_ENTRY(glm_ivec3_zero)
+  TEST_ENTRY(glm_ivec3_one)
+  TEST_ENTRY(glm_ivec3_add)
+  TEST_ENTRY(glm_ivec3_adds)
+  TEST_ENTRY(glm_ivec3_sub)
+  TEST_ENTRY(glm_ivec3_subs)
+  TEST_ENTRY(glm_ivec3_mul)
+  TEST_ENTRY(glm_ivec3_scale)
+  TEST_ENTRY(glm_ivec3_distance2)
+  TEST_ENTRY(glm_ivec3_distance)
+  TEST_ENTRY(glm_ivec3_maxv)
+  TEST_ENTRY(glm_ivec3_minv)
+  TEST_ENTRY(glm_ivec3_clamp)
+
+  TEST_ENTRY(glmc_ivec3)
+  TEST_ENTRY(glmc_ivec3_copy)
+  TEST_ENTRY(glmc_ivec3_zero)
+  TEST_ENTRY(glmc_ivec3_one)
+  TEST_ENTRY(glmc_ivec3_add)
+  TEST_ENTRY(glmc_ivec3_adds)
+  TEST_ENTRY(glmc_ivec3_sub)
+  TEST_ENTRY(glmc_ivec3_subs)
+  TEST_ENTRY(glmc_ivec3_mul)
+  TEST_ENTRY(glmc_ivec3_scale)
+  TEST_ENTRY(glmc_ivec3_distance2)
+  TEST_ENTRY(glmc_ivec3_distance)
+  TEST_ENTRY(glmc_ivec3_maxv)
+  TEST_ENTRY(glmc_ivec3_minv)
+  TEST_ENTRY(glmc_ivec3_clamp)
+
+  /* ivec4 */
+  TEST_ENTRY(glm_ivec4)
+  TEST_ENTRY(glm_ivec4_copy)
+  TEST_ENTRY(glm_ivec4_zero)
+  TEST_ENTRY(glm_ivec4_one)
+  TEST_ENTRY(glm_ivec4_add)
+  TEST_ENTRY(glm_ivec4_adds)
+  TEST_ENTRY(glm_ivec4_sub)
+  TEST_ENTRY(glm_ivec4_subs)
+  TEST_ENTRY(glm_ivec4_mul)
+  TEST_ENTRY(glm_ivec4_scale)
+  TEST_ENTRY(glm_ivec4_distance2)
+  TEST_ENTRY(glm_ivec4_distance)
+  TEST_ENTRY(glm_ivec4_maxv)
+  TEST_ENTRY(glm_ivec4_minv)
+  TEST_ENTRY(glm_ivec4_clamp)
+
+  TEST_ENTRY(glmc_ivec4)
+  TEST_ENTRY(glmc_ivec4_copy)
+  TEST_ENTRY(glmc_ivec4_zero)
+  TEST_ENTRY(glmc_ivec4_one)
+  TEST_ENTRY(glmc_ivec4_add)
+  TEST_ENTRY(glmc_ivec4_adds)
+  TEST_ENTRY(glmc_ivec4_sub)
+  TEST_ENTRY(glmc_ivec4_subs)
+  TEST_ENTRY(glmc_ivec4_mul)
+  TEST_ENTRY(glmc_ivec4_scale)
+  TEST_ENTRY(glmc_ivec4_distance2)
+  TEST_ENTRY(glmc_ivec4_distance)
+  TEST_ENTRY(glmc_ivec4_maxv)
+  TEST_ENTRY(glmc_ivec4_minv)
+  TEST_ENTRY(glmc_ivec4_clamp)
+
   /* structs */
   TEST_ENTRY(mat3s_identity_init)
   TEST_ENTRY(mat3s_zero_init)
